import "@testing-library/jest-dom";
import { render, screen } from "@testing-library/react";
import Header from "../../components/header";
import { useSession } from "next-auth/react";

jest.mock("next-auth/react", () => {
  return {
    useSession: jest.fn().mockReturnValue({
      status: "loading",
      data: null,
    }),
  };
});

describe("Header", () => {
  it("should render the header in a loading out state", () => {
    const { container } = render(<Header />);

    expect(container).toMatchSnapshot();
  });

  it("should render the header in an unauthenticated state", () => {
    const mockSession = {
      status: "unauthenticated",
      data: null,
    };

    useSession.mockReturnValueOnce(mockSession);

    const { container } = render(<Header />);

    expect(container).toMatchSnapshot();
  });

  it("should render the header in an authenticated state", () => {
    const mockSession = {
      status: "authenticated",
      data: { user: { email: "a", name: "Delta", image: "c" } },
    };

    useSession.mockReturnValueOnce(mockSession);

    const { container } = render(<Header />);

    expect(container).toMatchSnapshot();
  });
});
