import React from "react";
import Link from "next/link";
import { useRouter } from "next/router";
import { signOut, useSession } from "next-auth/react";

const Header = () => {
  const router = useRouter();
  const isActive = (pathname) => router.pathname === pathname;

  const { data: session, status } = useSession();

  let right = null;

  if (status === "loading") {
    right = (
      <div className="right">
        <p>Validating session ...</p>
        <style jsx>{`
          .right {
            margin-left: auto;
          }
        `}</style>
      </div>
    );
  }

  if (!session && status === "unauthenticated") {
    right = (
      <div className="center">
        <Link href="/api/auth/signin" data-active={isActive("/signup")}>
          Log in
        </Link>
        <style jsx>{`
          a {
            text-decoration: none;
            color: var(--geist-foreground);
            display: inline-block;
          }

          a + a {
            margin-left: 1rem;
          }

          .center {
            margin-left: auto;
          }

          .center a {
            border: 1px solid var(--geist-foreground);
            padding: 0.5rem 1rem;
            border-radius: 3px;
          }
        `}</style>
      </div>
    );
  }

  if (session && status === "authenticated") {
    right = (
      <div className="center">
        <Link href="/posts/create">
          <button>New post</button>
        </Link>
        <p>
          {session.user.name} ({session.user.email})
        </p>
        <button onClick={() => signOut()}>Log out</button>
        <style jsx>{`
          a {
            text-decoration: none;
            color: var(--geist-foreground);
            display: inline-block;
          }

          p {
            display: inline-block;
            font-size: 13px;
            padding-right: 1rem;
            padding-left: 1rem;
          }

          a + a {
            margin-left: 1rem;
          }

          .center {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            height: 100%;
            align-items: center;
            justify-content: center;
          }

          .center a {
            border: 1px solid var(--geist-foreground);
            padding: 0.5rem 1rem;
            border-radius: 3px;
          }

          button {
            border: 1px solid var(--geist-foreground);
            padding: 0.5rem 1rem;
            border-radius: 3px;
            border: none;
            height: 100%;
            margin: auto;
            width: max-content;
          }
        `}</style>
      </div>
    );
  }

  return (
    <nav>
      {right}
      <style jsx>{`
        nav {
          display: flex;
          padding: 2rem;
          align-items: center;
          justify-content: center;
        }
      `}</style>
    </nav>
  );
};

export default Header;
