import { getServerSession } from "next-auth/next";
import { options } from "./auth/[...nextauth]";
import { PostDB } from "../../lib/post-db";
import { PostService } from "../../services/post-service";

export default async function handle(req, res) {
  const session = await getServerSession(req, res, options);

  if (!session) {
    return res.status(401).json({ error: "You must be signed in to post." });
  }

  const postDB = new PostDB();
  const postService = new PostService(postDB);

  if (req.method === "POST") {
    const { title, content } = req.body;
    try {
      const post = await postService.createPost(
        { title, content },
        session.user.id
      );
      await res.revalidate("/");

      res.json(post);
    } catch (error) {
      res.status(500).json({ error: "Unable to create post." });
    }
  }
}
