import { getServerSession } from "next-auth/next";
import { options } from "./auth/[...nextauth]";
import prisma from "../../lib/prisma";

export default async function handle(req, res) {
  const session = await getServerSession(req, res, options);

  if (!session) {
    return res.status(401).json({ error: "You must be signed in to post." });
  }

  if (req.method === "POST") {
    const { title, content } = req.body;
    try {
      const result = await prisma.post.create({
        data: {
          title: title,
          content: content,
          user: { connect: { id: session?.user?.id } },
        },
      });
      await res.revalidate("/");
      res.json(result);
    } catch (error) {
      res.status(500).json({ error: "Unable to create post." });
    }
  }
}
