import Head from "next/head";
import Layout, { siteTitle } from "../components/layout";
import utilStyles from "../styles/utils.module.css";
import Link from "next/link";
import Date from "../components/date";
import prisma from "../lib/prisma";

export async function getStaticProps() {
  const allPostsData = await prisma.post.findMany({
    include: {
      user: true,
    },
  });
  const serializedPostsData = allPostsData.map((post) => {
    return {
      ...post,
      date: post.date.toISOString(),
      authorName: post.user?.name || "Unknown Author",
    };
  });

  return {
    props: { allPostsData: serializedPostsData },
    revalidate: 10,
  };
}

export default function Home({ allPostsData }) {
  return (
    <Layout home>
      <Head>
        <title>{siteTitle}</title>
      </Head>
      <section className={utilStyles.headingMd}>
        <p>Hello, I'm Erfan. I'm a lecturer at the FH Salzburg</p>
        <p>
          (This is a sample website - you’ll be building a site like this on{" "}
          <a href="https://nextjs.org/learn">our Next.js tutorial</a>.)
        </p>
      </section>
      <section className={`${utilStyles.headingMd} ${utilStyles.padding1px}`}>
        <h2 className={utilStyles.headingLg}>Blog</h2>
        <ul className={utilStyles.list}>
          {allPostsData.map(({ id, date, title }) => (
            <li className={utilStyles.listItem} key={id}>
              <Link href={`/posts/${id}`}>{title}</Link>
              <br />
              <small className={utilStyles.lightText}>
                <p>
                  <Date dateString={date} />
                </p>
              </small>
            </li>
          ))}
        </ul>
      </section>
    </Layout>
  );
}
