import { PostService } from "../post-service";

describe("PostService", () => {
  it("should create a post in the database", () => {
    const userId = "some_user_id";
    const mockedPostDB = {
      create: jest.fn(() => Promise.resolve()),
      update: jest.fn(),
    };
    const fakeData = {
      title: "Some title",
      content: "Some content",
    };

    const postService = new PostService(mockedPostDB);

    expect(postService.createPost(fakeData, userId)).resolves.not.toThrow();
    expect(mockedPostDB.create).toHaveBeenLastCalledWith(fakeData, userId);
  });

  it("should throw an error if title is longer than 50 chars", () => {
    const userId = "some_user_id";
    const mockedPostDB = {
      create: jest.fn(() => Promise.resolve()),
      update: jest.fn(() => Promise.resolve()),
    };
    const postService = new PostService(mockedPostDB);

    expect(() => {
      postService.createPost(
        {
          title: "Some string that is actually 100 characters long 1!11",
          content: "bla",
        },
        userId
      );
    }).toThrow();
    expect(mockedPostDB.create).not.toBeCalled();
  });
});
